from BrickBreaker.Scenes.game_over_scene import *
from BrickBreaker.Scenes.highscore_scene import *
from BrickBreaker.Scenes.main_menu_scene import *
from BrickBreaker.Scenes.playing_game_scene import *
from BrickBreaker.Scenes.win_scene import *
from BrickBreaker.Scenes.controls_scene import *
from BrickBreaker.Scenes.game_rules_scene import *
from BrickBreaker.Scenes.scene import *
